@@ -84,7 +84,7 @@ KParts::ReadOnlyPart *Core::createPart(const char *libname)
     KPluginLoader loader(QString::fromLatin1(libname));
     qCDebug(KONTACTINTERFACE_LOG) << loader.fileName();
     KPluginFactory *factory = loader.factory();
-    KParts::ReadOnlyPart *part = 0;
+    KParts::ReadOnlyPart *part = nullptr;
     if (factory) {
         part = factory->create<KParts::ReadOnlyPart>(this);
     }
@@ -106,7 +106,7 @@ void Core::Private::slotPartDestroyed(QObject *obj)
 {
     // the part was deleted, we need to remove it from the part map to not return
     // a dangling pointer in createPart
-    QMap<QByteArray, KParts::ReadOnlyPart *>::Iterator end = mParts.end();
+    const QMap<QByteArray, KParts::ReadOnlyPart *>::Iterator end = mParts.end();
     QMap<QByteArray, KParts::ReadOnlyPart *>::Iterator it = mParts.begin();
     for (; it != end; ++it) {
         if (it.value() == obj) {
